package tokens_test

import (
	"gitea.deepak.science/deepak/gogmagog/tokens"
	"github.com/stretchr/testify/assert"
	"net/http"
	"testing"
)

var (
	url     = ""
	authKey = "Authorization"
)

func requestWithAuth(header string) *http.Request {
	req, _ := http.NewRequest("GET", url, nil)
	req.Header.Add(authKey, header)

	return req
}

func TestHeaderParseBasic(t *testing.T) {
	assert := assert.New(t)

	header := "Bearer testing"
	req := requestWithAuth(header)

	assert.Equal("testing", tokens.TokenFromHeader(req))
}

func TestHeaderParseNoSpace(t *testing.T) {
	assert := assert.New(t)

	header := "Bearerxtesting"
	req := requestWithAuth(header)

	assert.Equal("testing", tokens.TokenFromHeader(req))
}

func TestHeaderParseUnicode(t *testing.T) {
	assert := assert.New(t)

	header := "Bearer 🌸"
	req := requestWithAuth(header)

	assert.Equal("🌸", tokens.TokenFromHeader(req))
}

func TestHeaderParseMalformed(t *testing.T) {
	assert := assert.New(t)

	header := "testing"
	req := requestWithAuth(header)

	assert.Equal("", tokens.TokenFromHeader(req))
}
